==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: hu\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "Munkaidő nyílvántartás"
 ,"Munkaidő nyílvántartások"

]
, "Account"
: "Azonosító"

, "Time Account (Number - Title)"
: "Időazonosító (Szám - Cím)"

, "Billable"
: "Számlázható"

, "Cleared in"
: "Kiegyenlítve ekkor"

, "Invoice"
: ""

, "Cleared"
: "Kiegyenlítve"

, "Date"
: "Dátum"

, "Start time"
: "Kezdési idő"

, "End time"
: ""

, "Duration"
: "Időtartam"

, "Description"
: "Leírás"

, "Type"
: ""

, "Time Account closed"
: "Időazonosító lezárt"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Contract"
: ""

, "Title"
: "Cím"

, "Number"
: "Szám"

, "Price"
: ""

, "Status"
: "Állapot"

, "Billed"
: "Számlázott"

, "Cleared at"
: ""

, "Booking deadline"
: "Könyvelési határidő"

, "Responsible"
: ""

, "Cost Center"
: "Költséghely"

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "Időazonosító"
 ,"Időazonosítók"

]
, "Time Account - Status"
: "Időazonosító - Állapot"

, "closed"
: "zárt"

, "open"
: "nyitott"

, "Not a valid time"
: "Nem érvényes idő"

, "Time Account - Billed"
: ""

, "not yet billed"
: "még nem számlázott"

, "to bill"
: "számlázni"

, "billed"
: "számlázott"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: "Kiegyenlítve ekkor"

, "Select Time Account..."
: "Időazonosító kiválasztása..."

, "Start"
: "Kezdés"

, "not set"
: "nincs megadva"

, "End"
: ""

, "Enter description..."
: "Leírás megadása..."

, "Need for Clarification"
: ""

, "Failed"
: "Hibás"

, "Could not save {0}."
: "{0} nem menthető."

, "Booking deadline for this Timeaccount has been exceeded."
: "Könyvelési határidő ehhez az időazonosítóhoz lejárt."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Saját könyvelése"

, "The grant to add Timesheets to this Timeaccount"
: "Munkaidő nyílvántartás hozzáadásának joga ehhez az időazonosítóhoz"

, "View All"
: "Minden megtekintése"

, "The grant to view Timesheets of other users"
: "Másik felhasználók munkaidő nyílvántartásának megtekintési joga"

, "Book All"
: "Minden könyvelése"

, "The grant to add Timesheets for other users"
: "Másik felhasználókhoz munkaidő nyílvántartás hozzáadásának joga"

, "Manage Clearing"
: "Kiegyenlítések kezelése"

, "The grant to manage clearing of Timesheets"
: "Munkaidő nyílvántartás kiegyenlítések kezelésének joga"

, "without contract"
: ""

, "without responsible"
: ""

, "timeframe"
: "időkeret"

, "summary"
: "összesen"

, "Total Timesheets"
: "Összes munkaidő nyílvántartások"

, "Billable Timesheets"
: "Számlázható munkaidő nyílvántartások"

, "Total Time"
: "Összes idő"

, "Time of Billable Timesheets"
: "Számlázható munkaidő nyílvántartások ideje"

, "Detail"
: "Részletek"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Munkaidő nyílvántartások exportálása"

, "Export as ODS"
: "Exportálás ODS-be"

, "Export as CSV"
: "Exportálás CSV-be"

, "Export as ..."
: "Exportálás másként ..."

, "Add New Timeaccount"
: ""

, "Unit"
: "Egység"

, "Unit Price"
: "Egységár"

, "Budget"
: "Költség"

, "Timesheets are billable"
: "Munkaidő nyílvántartás számlázható"

, "Access"
: "Engedélyek"

, "Permissions"
: "Engedélyek"

, "Show closed"
: "Lezártak mutatása"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "Munkaidő nyílvántartások ODS exportálásának beállítása"

, "Use this configuration for the timesheet ODS export."
: "Használd ezt a beállítást a munkaidő nyílvántartás ODS exportálására."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "alapértelmezett"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "semmi"

, "last week"
: "múlt hét"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Időazonosítók kezelése"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Időazonosítók hozzáadása, szerkesztése és törlése (beleértve minden munkaidő nyilvántartási jogot)"

, "Add timeaccounts"
: "Időazonosító hozzáadása"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""

, "My Timesheets today"
: "Mai munkaidőm"

, "My Timesheets this week"
: "Heti munkaidőm"

, "My Timesheets last week"
: "Múlt heti munkaidőm"

, "My Timesheets this month"
: "Havi munkaidőm"

, "My Timesheets last month"
: "Múlt havi munkaidőm"

, "Timeaccounts to bill"
: "Számlázandó időazonosítók"

, "Timeaccounts not yet billed"
: "Még nem számlázott időazonosítók"

, "Timeaccounts already billed"
: "Kiszámlázott időazonosítók"

, "Timetracker"
: "Munkaidő-követés"

, "Timesheet"
: "Munkaidő nyílvántartás"

, "Timeaccount"
: ""

, "Time Account"
: "Időazonosító"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "időkeret"

, "summary"
: "összesen"

, "Total Timesheets"
: "Összes munkaidő nyílvántartások"

, "Billable Timesheets"
: "Számlázható munkaidő nyílvántartások"

, "Total Time"
: "Összes idő"

, "Time of Billable Timesheets"
: "Számlázható munkaidő nyílvántartások ideje"

, "Description"
: "Leírás"

, "Detail"
: "Részletek"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Munkaidő nyílvántartások exportálása"

, "Export as ODS"
: "Exportálás ODS-be"

, "Export as CSV"
: "Exportálás CSV-be"

, "Export as ..."
: "Exportálás másként ..."

, "Timesheet, Timesheets"
: [
  "Munkaidő nyílvántartás"
 ,"Munkaidő nyílvántartások"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Hibás"

, "Could not save {0}."
: "{0} nem menthető."

, "Booking deadline for this Timeaccount has been exceeded."
: "Könyvelési határidő ehhez az időazonosítóhoz lejárt."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Egység"

, "Unit Price"
: "Egységár"

, "Factor"
: ""

, "Budget"
: "Költség"

, "Status"
: "Állapot"

, "closed"
: "zárt"

, "open"
: "nyitott"

, "Cleared In"
: "Kiegyenlítve ekkor"

, "Cleared at"
: ""

, "Cost Center"
: "Költséghely"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Munkaidő nyílvántartás számlázható"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Időazonosító"
 ,"Időazonosítók"

]
, "Number"
: "Szám"

, "Title"
: "Cím"

, "Access"
: "Engedélyek"

, "Permissions"
: "Engedélyek"

, "Time Account - Billed"
: ""

, "not yet billed"
: "még nem számlázott"

, "to bill"
: "számlázni"

, "billed"
: "számlázott"

, "Time Account - Status"
: "Időazonosító - Állapot"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Saját könyvelése"

, "The grant to add Timesheets to this Timeaccount"
: "Munkaidő nyílvántartás hozzáadásának joga ehhez az időazonosítóhoz"

, "View All"
: "Minden megtekintése"

, "The grant to view Timesheets of other users"
: "Másik felhasználók munkaidő nyílvántartásának megtekintési joga"

, "Book All"
: "Minden könyvelése"

, "The grant to add Timesheets for other users"
: "Másik felhasználókhoz munkaidő nyílvántartás hozzáadásának joga"

, "Manage Clearing"
: "Kiegyenlítések kezelése"

, "The grant to manage clearing of Timesheets"
: "Munkaidő nyílvántartás kiegyenlítések kezelésének joga"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Lezártak mutatása"

, "Timesheets ODS export configuration"
: "Munkaidő nyílvántartások ODS exportálásának beállítása"

, "Use this configuration for the timesheet ODS export."
: "Használd ezt a beállítást a munkaidő nyílvántartás ODS exportálására."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "alapértelmezett"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "semmi"

, "last week"
: "múlt hét"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Kiegyenlítve ekkor"

, "Billed"
: "Számlázott"

, "Booking deadline"
: "Könyvelési határidő"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Azonosító"

, "Time Account (Number - Title)"
: "Időazonosító (Szám - Cím)"

, "Billable"
: "Számlázható"

, "Cleared"
: "Kiegyenlítve"

, "Date"
: "Dátum"

, "Start time"
: "Kezdési idő"

, "End time"
: ""

, "Duration"
: "Időtartam"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Időazonosító lezárt"

, "Timetracker"
: "Munkaidő-követés"

, "Timeaccounts to bill"
: "Számlázandó időazonosítók"

, "Timeaccounts not yet billed"
: "Még nem számlázott időazonosítók"

, "Timeaccounts already billed"
: "Kiszámlázott időazonosítók"

, "My Timesheets today"
: "Mai munkaidőm"

, "My Timesheets this week"
: "Heti munkaidőm"

, "My Timesheets last week"
: "Múlt heti munkaidőm"

, "My Timesheets this month"
: "Havi munkaidőm"

, "My Timesheets last month"
: "Múlt havi munkaidőm"

, "Manage timeaccounts"
: "Időazonosítók kezelése"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Időazonosítók hozzáadása, szerkesztése és törlése (beleértve minden munkaidő nyilvántartási jogot)"

, "Add timeaccounts"
: "Időazonosító hozzáadása"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""






, "Timesheet"
: "Munkaidő nyílvántartás"

, "Timeaccount"
: ""

, "Time Account"
: "Időazonosító"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
